import {
  isArray,
  isObject,
  isPrimitive
} from "./chunk-EOHXRMVQ.js";

// src/common/data/object.ts
function objectMap(obj, fn) {
  if (!isObject(obj))
    return {};
  return Object.fromEntries(
    Object.entries(obj).map(([k, v]) => {
      const r = fn(k, v);
      if (isArray(r) && r.length === 2)
        return r;
      return [k, r];
    }).filter((v) => v != null)
  );
}
function objectMergeDisposable(a, b) {
  if (b.dispose && a.dispose) {
    b.dispose.add(a.dispose);
  }
  return Object.assign(a, b);
}
function objectIsEmpty(obj) {
  return Object.keys(obj).length <= 0;
}
function objectPick(obj, ...keys) {
  return Object.fromEntries(keys.filter((key) => key in obj).map((key) => [key, obj[key]]));
}
function objectInclusivePick(obj, ...keys) {
  return Object.fromEntries(keys.map((key) => [key, obj[key]]));
}
function objectOmit(obj, ...keys) {
  return Object.fromEntries(Object.entries(obj).filter(([key]) => !keys.includes(key)));
}
function objectPlain(obj, maxDepth = 99) {
  const cycle = [];
  function handleObject(obj2, depth) {
    if (depth >= maxDepth)
      return void 0;
    if (isPrimitive(obj2))
      return obj2;
    if (cycle.includes(obj2))
      return void 0;
    cycle.push(obj2);
    if (Array.isArray(obj2))
      return obj2.map((o) => handleObject(o, depth + 1));
    if (isObject(obj2)) {
      const nobj = {};
      for (const [key, value] of Object.entries(obj2))
        nobj[key] = handleObject(value, depth + 1);
      return nobj;
    }
    return void 0;
  }
  return handleObject(obj, 0);
}

export {
  objectMap,
  objectMergeDisposable,
  objectIsEmpty,
  objectPick,
  objectInclusivePick,
  objectOmit,
  objectPlain
};
//# sourceMappingURL=chunk-LD3DLTTO.js.map